local options = MissionMinder.options;
local L = LibStub("AceLocale-3.0"):GetLocale("MissionMinder");
local DEBUG = MissionMinder.debug;

MissionMinder.blizzfix = {};
local addon = MissionMinder.blizzfix;

local function hidePlacerFrame()
	if ( GarrisonFollowerPlacerFrame:IsShown() ) then
		GarrisonFollowerPlacerFrame:Hide();
	end
end

local function PreloadMissionModels(...)
	local missionID = ...;
	if ( C_Garrison.GetMissionDisplayIDs(missionID) == nil ) then
		return; -- If no values returned, then return without preloading
	end

	addon.MissionCompletePreload_LoadMission(...);
end

local function refreshMissionCounters(...)
	local self = GarrisonMissionFrame.MissionTab.MissionPage
	local mission = self.missionInfo;

	if ( self:IsShown() and mission ) then
		GarrisonMissionFrame.followerCounters = C_Garrison.GetBuffedFollowersForMission(mission.missionID)
		GarrisonMissionFrame.followerTraits = C_Garrison.GetFollowersTraitsForMission(mission.missionID);
		GarrisonFollowerList_UpdateFollowers(GarrisonMissionFrame.FollowerList);
	end
end

local frame = CreateFrame("Frame");
local function handleEvent(self, event, ...)
	if ( event == "GARRISON_FOLLOWER_LIST_UPDATE" ) then
		refreshMissionCounters(...);
	end
end
frame:SetScript("OnEvent", handleEvent);
frame:RegisterEvent("GARRISON_FOLLOWER_LIST_UPDATE");


function addon.initialize()
	-- Fix problem where StartDrag on an empty party member will cause the GarrisonFollowerPlacerFrame to show
	--and NEVER hide. This proceeds to eat all mouse events and cause the GarrisonMissionFrame to be noninteractive.
	--The placer frame uses UIParent, so is present even after closing the GarrisonMissionFrame.
	--Typically a /reload ui is required (or manually hiding the placer frame)
	local partyFollowers = GarrisonMissionFrame.MissionTab.MissionPage.Followers;
	for i = 1, #partyFollowers do
		-- We reuse the GarrisonFollowerListButton code as it actually already does a proper check
		partyFollowers[i]:SetScript("OnDragStop", GarrisonFollowerListButton_OnDragStop);
	end

	-- For added measure clearMouse now hides PlacerFrame if it somehow happens to be visible on accident
	hooksecurefunc("GarrisonMissionFrame_ClearMouse", hidePlacerFrame);



	-- C_Garrison.GetMissionDisplayIDs(missionID) will return nil in certain scenarios, and the blizzard code
	--does not handle nils. This case seems to occur when models have already been preloaded, and we try to
	--preload a second time.
	addon.MissionCompletePreload_LoadMission = MissionCompletePreload_LoadMission;
	MissionCompletePreload_LoadMission = PreloadMissionModels;
end
